@@ -1,3 +1,4 @@
+import os
 def read_file(fname: str) -> str:
     file = open(fname, 'r')
     res = file.read()
@@ -8,3 +9,8 @@ def write_file(fname: str, content: str) -> str:
     file = open(fname, 'w')
     file.write(content)
     file.close()
+
+def mkdir(path, makedir=True):
+    if makedir:
+        os.mkdir(path)
+    return str(path.stem)
